@@ -144,6 +144,9 @@ class OdnoklassnikiManager(models.Manager):
 
         return api_call(method, **kwargs)
 
+    def fetch_one(self, *args, **kwargs):
+        return self.fetch(*args, **kwargs)
+
     @atomic
     def fetch(self, *args, **kwargs):
         '''
@@ -394,33 +397,6 @@ class OdnoklassnikiModel(models.Model):
         raise NotImplementedError("Property %s.slug should be specified" % self.__class__.__name__)
 
 
-# class OdnoklassnikiIDModel(OdnoklassnikiModel):
-#     class Meta:
-#         abstract = True
-#
-#     remote_id = models.BigIntegerField(u'ID', help_text=u'Уникальный идентификатор', unique=True)
-#
-#     @property
-#     def slug(self):
-#         return self.slug_prefix + str(self.remote_id)
-#
-#     def save(self, *args, **kwargs):
-#         '''
-#         In case of IntegrityError, caused by `remote_id` field make substitution and save again
-#         '''
-#         try:
-#             return super(OdnoklassnikiIDModel, self).save(*args, **kwargs)
-#         except IntegrityError, e:
-#             try:
-#                 assert self.remote_id and 'remote_id' in unicode(e)
-#                 instance = self.__class__.objects.get(remote_id=self.remote_id)
-#                 self._substitute(instance)
-#                 kwargs['force_insert'] = False
-#                 return super(OdnoklassnikiIDModel, self).save(*args, **kwargs)
-#             except (AssertionError, self.__class__.DoesNotExist):
-#                 raise e
-
-
 class OdnoklassnikiPKModel(OdnoklassnikiModel):
 
     class Meta:
@@ -431,177 +407,3 @@ class OdnoklassnikiPKModel(OdnoklassnikiModel):
     @property
     def slug(self):
         return '/'.join([self.slug_prefix, str(self.pk)])
-
-# class OdnoklassnikiCRUDManager(models.Manager):
-#
-#     def create(self, *args, **kwargs):
-#         instance = self.model(**kwargs)
-#         instance.save()
-#         return instance
-#
-#
-# class OdnoklassnikiCRUDModel(models.Model):
-#     class Meta:
-#         abstract = True
-#
-# list of required number of fields for updating model remotely
-#     fields_required_for_update = []
-#
-# flag should we update model remotely on save() and delete() methods
-#     _commit_remote = True
-#
-#     archived = models.BooleanField(u'В архиве', default=False)
-#
-#     def __init__(self, *args, **kwargs):
-#         self._commit_remote = kwargs.pop('commit_remote', self._commit_remote)
-#         super(OdnoklassnikiCRUDModel, self).__init__(*args, **kwargs)
-#
-#     def delete(self, commit_remote=None, *args, **kwargs):
-#         if not self.archived:
-#             self.delete_remote(commit_remote)
-#
-#     def restore(self, commit_remote=None, *args, **kwargs):
-#         if self.archived:
-#             self.restore_remote(commit_remote)
-#
-#     def save(self, commit_remote=None, *args, **kwargs):
-#         '''
-#         Update remote version of object before saving if data is different
-#         '''
-#         commit_remote = commit_remote if commit_remote is not None else self._commit_remote
-#         if commit_remote and COMMIT_REMOTE:
-#             if not self.pk and not self.fetched:
-#                 self.create_remote(**kwargs)
-#             elif self.pk and self.fields_changed:
-#                 self.update_remote(**kwargs)
-#         super(OdnoklassnikiCRUDModel, self).save(*args, **kwargs)
-#
-#     def create_remote(self, **kwargs):
-#         response = self.__class__.remote.api_call(
-#                 method='create', **self.prepare_create_params(**kwargs))
-#         self.remote_id = self.parse_remote_id_from_response(response)
-#         log.info("Remote object %s was created successfully with ID %s" \
-#                 % (self._meta.object_name, self.remote_id))
-#
-#     def update_remote(self, **kwargs):
-#         params = self.prepare_update_params_distinct(**kwargs)
-# sometimes response contains 1, sometimes remote_id
-#         response = self.__class__.remote.api_call(method='update', **params)
-#         if not response:
-#             message = "Error response '%s' while saving remote %s with ID %s and data '%s'" \
-#                     % (response, self._meta.object_name, self.remote_id, params)
-#             log.error(message)
-#             raise OdnoklassnikiContentError(message)
-#         log.info("Remote object %s with ID=%s was updated with fields '%s' successfully" \
-#                 % (self._meta.object_name, self.remote_id, params))
-#
-#     def delete_remote(self, commit_remote=None):
-#         '''
-#         Delete objects remotely and mark it archived localy
-#         '''
-#         commit_remote = commit_remote if commit_remote is not None else self._commit_remote
-#         if commit_remote and self.remote_id:
-#             params = self.prepare_delete_params()
-#             success = self.__class__.remote.api_call(method='delete', **params)
-#             model = self._meta.object_name
-#             if not success:
-#                 message = "Error response '%s' while deleting remote %s with ID %s" % (success, model, self.remote_id)
-#                 log.error(message)
-#                 raise OdnoklassnikiContentError(message)
-#             log.info("Remote object %s with ID %s was deleted successfully" % (model, self.remote_id))
-#
-#         self.archived = True
-#         self.save(commit_remote=False)
-#
-#     def restore_remote(self, commit_remote=None):
-#         '''
-#         Restore objects remotely and unmark it archived localy
-#         '''
-#         commit_remote = commit_remote if commit_remote is not None else self._commit_remote
-#         if commit_remote and self.remote_id:
-#             params = self.prepare_restore_params()
-#             success = self.__class__.remote.api_call(method='restore', **params)
-#             model = self._meta.object_name
-#             if not success:
-#                 message = "Error response '%s' while restoring remote %s with ID %s" % (success, model, self.remote_id)
-#                 log.error(message)
-#                 raise OdnoklassnikiContentError(message)
-#             log.info("Remote object %s with ID %s was restored successfully" % (model, self.remote_id))
-#
-#         self.archived = False
-#         self.save(commit_remote=False)
-#
-#     @property
-#     def fields_changed(self):
-#         old = self.__class__.objects.get(remote_id=self.remote_id)
-#         return old.__dict__ != self.__dict__
-#
-#     def prepare_update_params_distinct(self, **kwargs):
-#         '''
-#         Return dict with distinct set of fields for update
-#         '''
-#         old = self.__class__.objects.get(remote_id=self.remote_id)
-#         fields_new = self.prepare_update_params(**kwargs).items()
-#         fields_old = old.prepare_update_params(**kwargs).items()
-#         fields = dict(set(fields_new).difference(set(fields_old)))
-#         fields.update(dict([(k,v) for k,v in fields_new if k in self.fields_required_for_update]))
-#         return fields
-#
-#     @abstractmethod
-#     def prepare_create_params(self, **kwargs):
-#         """
-#         Prepare params for remote create object.
-#         Incoming params:
-#             **kwargs - fields, which model instance hasn't
-#
-#         return {param_key: val, ....}
-#         """
-#         raise NotImplementedError
-#
-#     @abstractmethod
-#     def prepare_update_params(self, **kwargs):
-#         """
-#         Prepare params for remote update object.
-#         Incoming params:
-#             **kwargs - fields, which model instance hasn't
-#
-#         return {param_key: val, ....}
-#         """
-#         raise NotImplementedError
-#
-#     @abstractmethod
-#     def prepare_delete_params(self):
-#         """
-#         Prepar params for remote delete object.
-#
-#         return {param_key: val, ....}
-#         """
-#         raise NotImplementedError
-#
-#     @abstractmethod
-#     def prepare_restore_params(self):
-#         """
-#         Prepar params for remote restore object.
-#
-#         return {param_key: val, ....}
-#         """
-#         return self.prepare_delete_params()
-#
-#     @abstractmethod
-#     def parse_remote_id_from_response(self, response):
-#         """
-#         Extract remote_id from response from API create call.
-#         Incoming param:
-#             response - API crete call response
-#
-#         return 'some_id'
-#         """
-#         raise NotImplementedError
-#
-#     def check_remote_existance(self, *args, **kwargs):
-#         self.refresh(*args, **kwargs)
-#         if self.archived:
-#             self.archive(commit_remote=False)
-#             return False
-#         else:
-#             return True
